"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const clone_error_1 = require("./clone-error");
/**
 * Returns a cloneable copy of the given context object.
 * @internal
 */
function cloneContext(context) {
    return {
        cwd: context.cwd,
        concurrency: context.concurrency,
        dev: context.dev,
        debug: context.debug,
    };
}
exports.cloneContext = cloneContext;
/**
 * Creates a `Context` object from a `ContextClone`.
 * @internal
 */
function createContext(messenger, messageId, context) {
    return {
        ...context,
        logger: {
            log(message, data) {
                messenger.postReply(createLogReply("info" /* Info */, messageId, message, data));
            },
            debug(message, data) {
                if (context.debug) {
                    messenger.postReply(createLogReply("debug" /* Debug */, messageId, message, data));
                }
            },
            warn(warning, data) {
                messenger.postReply(createLogReply("warning" /* Warning */, messageId, warning, data));
            },
            error(error, data) {
                messenger.postReply(createLogReply("error" /* Error */, messageId, error, data));
            }
        }
    };
}
exports.createContext = createContext;
function createLogReply(level, to, msg, data) {
    let message = clone_error_1.cloneError(msg);
    return { type: "log", to, level, message, data };
}
//# sourceMappingURL=clone-context.js.map